| Title: | 'NiiVue' for R |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | Zhengjia Wang [aut, cre] |
| Maintainer: | Zhengjia Wang <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.2 |
| Built: | 2026-05-22 08:03:14 UTC |
| Source: | https://github.com/dipterix/niivuer |
Creates a widget that bridges 'NiiVue', a powerful 3D brain viewer and R-shiny
niivuer( volume_list = list(list(url = "https://niivue.com/demos/images/mni152.nii.gz", colormap = "gray"), list(url = "https://niivue.com/demos/images/hippo.nii.gz", colormap = "red")), mesh_list = list(list(url = "https://niivue.com/demos/images/BrainMesh_ICBM152.lh.mz3")), viewer_settings = list(setMultiplanarLayout = 2, setSliceMM = TRUE, setSliceType = 4), controller_settings = list(), ..., width = NULL, height = NULL, elementId = NULL )niivuer( volume_list = list(list(url = "https://niivue.com/demos/images/mni152.nii.gz", colormap = "gray"), list(url = "https://niivue.com/demos/images/hippo.nii.gz", colormap = "red")), mesh_list = list(list(url = "https://niivue.com/demos/images/BrainMesh_ICBM152.lh.mz3")), viewer_settings = list(setMultiplanarLayout = 2, setSliceMM = TRUE, setSliceType = 4), controller_settings = list(), ..., width = NULL, height = NULL, elementId = NULL )
volume_list |
list of items, each item is a volume file |
mesh_list |
list of items, each item is a mesh file |
viewer_settings |
initial call to set viewer status |
controller_settings |
initial controller settings |
... |
application settings |
width, height
|
widget size |
elementId |
passed to |
A 'niivuer' widget
if( interactive() ) { niivuer() }if( interactive() ) { niivuer() }
Output and render functions for using niivuer within Shiny applications and interactive Rmd documents.
niivuerOutput(outputId, width = "100%", height = "500px") renderNiivuer(expr, env = parent.frame(), quoted = FALSE)niivuerOutput(outputId, width = "100%", height = "500px") renderNiivuer(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height
|
Must be a valid CSS unit (like |
expr |
An expression that generates a niivuer |
env |
The environment in which to evaluate |
quoted |
Is |